RequestArg class

http 请求参数定义。对各个 http 客户端的适配工作应该在各个工程中完成。

Constructors

RequestArg({required Map<String, dynamic> body, required Uri url})
创建请求参数。
const
RequestArg.fromPattern(HttpRule rule, Map<String, dynamic> req)
根据请求路径模板创建请求参数。
factory

Properties

body Map<String, dynamic>
过滤后的请求参数。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url Uri
请求 url,没有 schema 和 host 部分。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited